Class: Array
- Inherits:
-
Object
- Object
- Array
- Defined in:
- lib/allotment/array.rb
Overview
Ruby Array
Instance Method Summary collapse
-
#average ⇒ Object
If an array is all numbers This displayes the mean average.
Instance Method Details
#average ⇒ Object
If an array is all numbers This displayes the mean average
6 7 8 |
# File 'lib/allotment/array.rb', line 6 def average inject(:+).to_f / size end |